import typer
import openai
import json
import importlib.resources
import pathlib
import sys
from typing import Any

PACKAGEDIR = pathlib.Path(__file__).parent.absolute()
app = typer.Typer()


def read_config():
    with open(PACKAGEDIR / "config.json") as f:
        config = json.load(f)
        return config


def write_config(config_dict):
    config = read_config()
    config.update(config_dict)
    with open(PACKAGEDIR / "config.json", "w") as f:
        json.dump(config, f)
        return config


@app.command()
def config():
    config = read_config()
    typer.echo(config)


@app.command()
def api(api_key: str):
    config = read_config()
    config["api_key"] = api_key
    write_config(config)
    print(config)
    typer.echo(f"API key {api_key} saved")


@app.command()
def temp(temperature: float):
    config = read_config()
    config["temperature"] = temperature
    write_config(config)
    print(config)
    typer.echo(f"Temperature {temperature} saved")


@app.command()
def tokens(tokens: int):
    config = read_config()
    config["max_tokens"] = tokens
    write_config(config)
    print(config)
    typer.echo(f"Tokens {tokens} saved")


@app.command()
def it(
    question: str = typer.Argument(..., help="Question to ask"),
):
    """
    Welcome to ASK it, set your api with command "ask api "your open api key here".
    Then ask questions with "ask it "your question here?"
    Make sure to finish the question with a question mark.
    """
    config = read_config()
    if config["api_key"] == "":
        typer.echo("Please set your API key with command ask api")
        raise typer.Exit(1)
    else:
        openai.api_key = config["api_key"]
        response = openai.Completion.create(
            engine="text-davinci-002",
            prompt=question,
            temperature=config["temperature"],
            max_tokens=config["max_tokens"],
        )
        typer.echo(response["choices"][0]["text"])


if __name__ == "__main__":
    app()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['askit']

package_data = \
{'': ['*']}

install_requires = \
['openai>=0.25.0,<0.26.0', 'typer[all]>=0.6.1,<0.7.0']

entry_points = \
{'console_scripts': ['ask = askit.main:app']}

setup_kwargs = {
    'name': 'askit',
    'version': '0.1.4.2',
    'description': 'Ask OpenAI your question right inside your terminal',
    'long_description': '# AskAI\n\nAsk OpenAI your question from the command line and get a response. Super janky right now.\n\n# Installation\n\n    pip install askit\n\n# Add API key first time use\n\n    ask api your-openai-key-goes-here\n\n# Usage\n\n    ask it "Is this a well formulated question for openAI?"\n\n# Notes\nYou need to have your question in a string format, and you must end your question with a question mark or it won\'t work.\n\n"Questions must look like this?"\n\nThis is super janky. Feedback welcomed.',
    'author': 'Phil Harper',
    'author_email': 'phil@imrge.co',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
